# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## v0.3.0 - 2025-05-08
- Added `@attach_client` and `TyperdriveClient`

## v0.2.0 - 2025-05-04
- Enabled access to settings and cache through command function parameters


## v0.1.0 - 2025-05-02
- Forked from typer-repyt and released as new package.
